@@ -354,6 +354,27 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         invoice = self.wrapper.invoice
         self.assertEqual(invoice.number, '159')
 
+    def test_order_identifier(self):
+        """
+        test_order_identifier
+        """
+        invoice = self.wrapper.invoice
+        self.assertEqual(invoice.order_identifier, 'TIL21222')
+
+    def test_seller_reference_identifier(self):
+        """
+        seller_reference_identifier
+        """
+        invoice = self.wrapper.invoice
+        self.assertEqual(invoice.seller_reference_identifier, 'MYY21231')
+
+    def test_buyer_reference_identifier(self):
+        """
+        test_buyer_reference_identifier
+        """
+        invoice = self.wrapper.invoice
+        self.assertEqual(invoice.buyer_reference_identifier, None)
+
     def test_invoice_free_text(self):
         """
         test_invoice_free_text
@@ -471,7 +492,7 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         """
         row = self.wrapper.rows[2]
         self.assertEqual(row.name, '')
-        self.assertEqual(row.article_identifier, '')
+        self.assertEqual(row.article_identifier, None)
         self.assertEqual(row.quantity, None)
         self.assertEqual(row.unit_price, None)
         self.assertEqual(row.total_taxed, None)
