@@ -59,6 +59,9 @@ class Invoice(object):
     payment_overdue_percent = None
     typecode = None
     type_text = None
+    order_identifier = None
+    seller_reference_identifier = None
+    buyer_reference_identifier = None
 
     def set_epi_details(self, doc):
         epi_details = doc.EpiDetailsSet
@@ -132,6 +135,18 @@ class Invoice(object):
                     vat_amount[0].attributes.get('amountcurrencyidentifier',
                                                  '')
 
+            order_identifier = invoice_details[0].OrderIdentifierSet
+            if len(order_identifier) > 0:
+                self.order_identifier = order_identifier[0].text
+
+            seller_reference_identifier = invoice_details[0].SellerReferenceIdentifierSet
+            if len(seller_reference_identifier) > 0:
+                self.seller_reference_identifier = seller_reference_identifier[0].text
+
+            buyer_reference_identifier = invoice_details[0].BuyerReferenceIdentifierSet
+            if len(buyer_reference_identifier) > 0:
+                self.buyer_reference_identifier = buyer_reference_identifier[0].text
+
             free_text = invoice_details[0].InvoiceFreeTextSet
             if len(free_text) > 0:
                 self.free_text = free_text.as_string(delim='\n')
@@ -519,7 +534,6 @@ class Row(object):
 
     def __init__(self, row):
         self.name = row.ArticleNameSet.as_string()
-        self.article_identifier = row.ArticleIdentifierSet.as_string()
 
         def get_QuantitySetData(set):
             if len(set) > 0:
@@ -544,6 +558,10 @@ class Row(object):
         if self.quantity < 1:
             get_QuantitySetData(row.OrderedQuantitySet)
 
+        article_identifier = row.ArticleIdentifierSet
+        if len(article_identifier) > 0:
+            self.article_identifier = article_identifier[0].text
+
         unit_price = row.UnitPriceAmountSet
         if len(unit_price) > 0 and unit_price[0]:
             _unit_price = str(unit_price[0].text).strip()
@@ -611,7 +629,8 @@ class Row(object):
             'total_taxed': self.total_taxed,
             'total_untaxed': self.total_untaxed,
             'vat_amount': self.vat_amount,
-            'date': self.date}
+            'date': self.date,
+            'account_dimension_text': self.account_dimension_text}
 
 
 class FinvoiceWrapper(object):
